Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(109)

Unified Diff: ui/app_list/presenter/app_list_presenter_delegate.h

Issue 1890583002: Renaming App List Shower to App List Presenter (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/app_list/presenter/app_list_presenter_delegate.h
diff --git a/ui/app_list/shower/app_list_shower_delegate.h b/ui/app_list/presenter/app_list_presenter_delegate.h
similarity index 70%
rename from ui/app_list/shower/app_list_shower_delegate.h
rename to ui/app_list/presenter/app_list_presenter_delegate.h
index 76b35731f1760c0e32db62d73446d66b1d1c1313..93e71e7e4f1091a005679fa6e1fee1719b1b3fc9 100644
--- a/ui/app_list/shower/app_list_shower_delegate.h
+++ b/ui/app_list/presenter/app_list_presenter_delegate.h
@@ -2,10 +2,10 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_APP_LIST_SHOWER_APP_LIST_SHOWER_DELEGATE_H_
-#define UI_APP_LIST_SHOWER_APP_LIST_SHOWER_DELEGATE_H_
+#ifndef UI_APP_LIST_PRESENTER_APP_LIST_PRESENTER_DELEGATE_H_
+#define UI_APP_LIST_PRESENTER_APP_LIST_PRESENTER_DELEGATE_H_
-#include "ui/app_list/shower/app_list_shower_export.h"
+#include "ui/app_list/presenter/app_list_presenter_export.h"
namespace aura {
class Window;
@@ -20,12 +20,13 @@ namespace app_list {
class AppListView;
class AppListViewDelegate;
// Delegate of AppListShower which allows to customize AppListShower's behavior.
// The design of this interface was heavily influenced by the needs of Ash's
-// app list implementation (see ash::AppListShowerDelegate).
-class APP_LIST_SHOWER_EXPORT AppListShowerDelegate {
+// app list implementation (see ash::AppListPresenterDelegate).
+class APP_LIST_PRESENTER_EXPORT AppListPresenterDelegate {
public:
- virtual ~AppListShowerDelegate() {}
+ virtual ~AppListPresenterDelegate() {}
// Returns the delegate for the app list view, possibly creating one.
virtual AppListViewDelegate* GetViewDelegate() = 0;
@@ -52,4 +53,4 @@ class APP_LIST_SHOWER_EXPORT AppListShowerDelegate {
} // namespace app_list
-#endif // UI_APP_LIST_SHOWER_APP_LIST_SHOWER_DELEGATE_H_
+#endif // UI_APP_LIST_PRESENTER_APP_LIST_PRESENTER_DELEGATE_H_
« no previous file with comments | « ui/app_list/presenter/app_list_presenter.gyp ('k') | ui/app_list/presenter/app_list_presenter_delegate_factory.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -20,12 +20,13 @@ namespace app_list {
class AppListView;
class AppListViewDelegate;
-// Delegate of AppListShower which allows to customize AppListShower's behavior.
+// Delegate of AppListPresenter which allows to customize AppListPresenter's
+// behavior.
// The design of this interface was heavily influenced by the needs of Ash's
This is Rietveld 408576698